@@ -37,7 +37,8 @@ private Q_SLOTS:
 
         const char expected[] =
             "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n"
-            "<gpx xmlns=\"http://www.topografix.com/GPX/1/1\" xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\" xsi:schemaLocation=\"http://www.topografix.com/GPX/1/1\">\n"
+            "<gpx xmlns=\"http://www.topografix.com/GPX/1/1\" xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\" "
+            "xsi:schemaLocation=\"http://www.topografix.com/GPX/1/1\">\n"
             "    <metadata>\n"
             "        <link href=\"https://apps.kde.org/itinerary\">\n"
             "            <text>KDE Itinerary</text>\n"
